@@ -4,14 +4,16 @@ cheetan is licensed under the MIT license.
 copyright (c) 2006 cheetan all right reserved.
 http://php.cheetan.net/
 -----------------------------------------------------------------------------*/
-class CDBMysql extends CDBCommon
-{
-	function connect( $host, $user, $pswd, $db )
-	{
-		$connect = mysql_connect( $host, $user, $pswd );
-		if( $connect )
-		{
-			mysql_select_db( $db, $connect );
+class CDBMysql extends CDBCommon {
+
+	function connect($config) {
+		$host = $config['host'];
+		if (!empty($config['port'])) {
+			$host .= ':' . $config['port'];
+		}
+		$connect = mysql_connect($host, $config['user'], $config['pswd']);
+		if($connect) {
+			mysql_select_db($config['db'], $connect);
 		}
 		return $connect;
 	}
@@ -19,7 +21,29 @@ class CDBMysql extends CDBCommon
 	
 	function query( $query, $connect )
 	{
-		return mysql_query( $query, $connect );
+		$this->last_query	= $query;
+	    list($usec, $sec)	= explode( " ", microtime() ); 
+		$time				= (float)$sec + (float)$usec;
+		$res				= mysql_query( $query, $connect );
+	    list($usec, $sec)	= explode( " ", microtime() ); 
+		$this->query_time	= ( (float)$sec + (float)$usec ) - $time;
+		if( $res )
+		{
+			if( $last_insert_id = mysql_insert_id( $connect ) )
+			{
+				$this->last_insert_id	= $last_insert_id;
+			}
+			if( $affected = mysql_affected_rows( $connect ) )
+			{
+				$this->affected_rows	= $affected;
+			}
+		}
+		else
+		{
+			$this->last_error	= mysql_error( $connect );
+		}
+		$this->_push_log();
+		return $res;
 	}
 	
 	
