@@ -46,16 +46,14 @@ class CModel extends CObject
 	}
 
 
-	function find( $condition = "", $order = "", $limit = "", $group = "" )
-	{
-		return $this->db->findall( $this->table, $condition, $order, $limit, $group, $this->name );
+	function find($condition = null, $order = "", $limit = "", $group = "") {
+		return $this->db->findall($this->table, $condition, $order, $limit, $group, $this->name);
 	}
 	
 	
-	function findone( $condition = "", $order = "" )
-	{
-		$result	= $this->find( $condition, $order, 1 );
-		if( count( $result ) )	return $result[0];
+	function findone($condition = null, $order = "") {
+		$result	= $this->find($condition, $order, 1);
+		if(count($result))	return $result[0];
 		return FALSE;
 	}
 	
@@ -74,9 +72,8 @@ class CModel extends CObject
 	}
 	
 	
-	function getcount( $condition = "", $limit = "" )
-	{
-		return $this->db->getcount( $this->table, $condition, $limit, $this->name );
+	function getcount($condition = null, $limit = "") {
+		return $this->db->getcount($this->table, $condition, $limit, $this->name);
 	}
 
 
@@ -106,56 +103,57 @@ class CModel extends CObject
 	}
 
 
-	function del( $condition )
-	{
-		return $this->db->del( $this->table, $condition, $this->name );
+	function del($condition) {
+		return $this->db->del($this->table, $condition, $this->name);
 	}
 	
 	
-	function validate( $datas )
-	{
+	function validate($data) {
 		$ret		= TRUE;
 		$validater	= &$this->controller->validate;
-		foreach( $datas as $key => $data )
-		{
-			if( array_key_exists( $key, $this->validatefunc ) )
-			{
-				$func	= $this->validatefunc[$key];
-				if( method_exists( $validater, $func ) )
-				{
-					$this->validateresult[$key]	= $validater->$func( $data );
-					if( !$this->validateresult[$key] )
-					{
-						$ret	= FALSE;
+		foreach ($data as $key => $value) {
+			if (array_key_exists($key, $this->validatefunc)) {
+				$funcs	= $this->validatefunc[$key];
+				$errors	= $this->validatemsg[$key];
+				if (!is_array($funcs)) $funcs = array($funcs);
+				if (!is_array($errors)) $errors = array($errors);
+				foreach ($funcs as $i => $func) {
+					if (method_exists($validater, $func)) {
+						if (!$validater->$func($value)) {
+							if (array_key_exists($key, $this->validatemsg) && empty($this->validateresult[$key])) {
+								$this->validateresult[$key]	= $errors[$i];
+							}
+							$ret	= FALSE;
+						}
 					}
 				}
 			}
 		}
-		
 		return $ret;
 	}
 	
 	
-	function validatemsg( $datas )
-	{
+	function validatemsg($data) {
 		$ret		= "";
 		$validater	= &$this->controller->validate;
-		foreach( $datas as $key => $data )
-		{
-			if( array_key_exists( $key, $this->validatefunc ) )
-			{
-				$func	= $this->validatefunc[$key];
-				if( method_exists( $validater, $func ) )
-				{
-					$this->validateresult[$key]	= $validater->$func( $data );
-					if( !$this->validateresult[$key] && array_key_exists( $key, $this->validatemsg ) )
-					{
-						$ret	.= $this->validatemsg[$key];
+		foreach ($data as $key => $value) {
+			if (array_key_exists($key, $this->validatefunc)) {
+				$funcs	= $this->validatefunc[$key];
+				$errors	= $this->validatemsg[$key];
+				if (!is_array($funcs)) $funcs = array($funcs);
+				if (!is_array($errors)) $errors = array($errors);
+				foreach ($funcs as $i => $func) {
+					if (method_exists($validater, $func)) {
+						if (!$validater->$func($value)) {
+							if (array_key_exists($key, $this->validatemsg) && empty($this->validateresult[$key])) {
+								$this->validateresult[$key]	= $errors[$i];
+								$ret .= $errors[$i];
+							}
+						}
 					}
 				}
 			}
 		}
-		
 		return $ret;
 	}
 	
